import type { Dictionary, RothkoKind, WithAria } from '@rothko-ui/system';
import React from 'react';
type StyleableComponents = 'errorText' | 'label';
type AriaAttributes = 'aria-label' | 'aria-describedby' | 'aria-details' | 'aria-labelledby' | 'aria-hidden' | 'aria-controls' | 'aria-haspopup' | 'aria-expanded' | 'aria-disabled' | 'aria-invalid' | 'aria-required' | 'aria-errormessage';
type CheckboxProps = {
    /**
     * The `id` attribute of the checkbox.
     * @type {string}
     */
    id?: string;
    /**
     * Specifies whether the checkbox is checked.
     * @type {boolean}
     * @default false
     */
    checked?: boolean;
    /**
     * The content to be displayed inside the checkbox.
     * @type {React.ReactNode}
     */
    children?: React.ReactNode;
    /**
     * CSS class name(s).
     * @type {string}
     */
    className?: string;
    /**
     * CSS class name(s) for the checkbox components.
     * @type {Object<StyleableComponents, string>}
     */
    classNames?: Dictionary<StyleableComponents, string>;
    /**
     * Specifies whether the checkbox is disabled.
     * @type {boolean}
     * @default false
     */
    disabled?: boolean;
    /**
     * Specifies whether there is an error with the checkbox.
     * @type {boolean}
     * @default false
     */
    error?: boolean;
    /**
     * The error text to be displayed when there is an error.
     * @type {string}
     * @default: 'Invalid'
     */
    errorText?: string;
    /**
     * The checkbox's semantic style.
     * @type {RothkoKind}
     */
    kind?: RothkoKind;
    /**
     * The callback function called when the checkbox value changes.
     */
    onChange?: (v: boolean) => void;
    /**
     * Specifies whether the checkbox is required.
     */
    required?: boolean;
    /**
     * The inline style for the checkbox.
     * @type {React.CSSProperties}
     */
    style?: React.CSSProperties;
    /**
     * Additional inline styles for the checkbox components.
     * @type {Object<StyleableComponents, React.CSSProperties>}
     */
    styles?: Partial<Record<StyleableComponents, React.CSSProperties>>;
};
declare const Checkbox: ({ id, "aria-label": ariaLabel, "aria-describedby": ariaDescribedBy, "aria-details": ariaDetails, "aria-labelledby": ariaLabelledBy, "aria-hidden": ariaHidden, "aria-controls": ariaControls, "aria-haspopup": ariaHasPopup, "aria-expanded": ariaExpanded, "aria-disabled": ariaDisabled, "aria-invalid": ariaInvalid, "aria-required": ariaRequired, "aria-errormessage": ariaErrorMessage, checked, children, className, classNames, disabled, error, kind, onChange, style, styles: stylesProp, errorText, }: WithAria<CheckboxProps, AriaAttributes>) => React.JSX.Element;
export default Checkbox;
